library(ggplot2)
library(magrittr)

## Read in data

data<-read.csv("SI 2 - Self-archiving policies - Palaeontology.csv")

## For preprints

summary(data$Preprints)

pdf(file="preprints.pdf")
data %>% ggplot(aes(Preprints))+ geom_bar()
dev.off()

## For postprints

summary(data$Postprints)

pdf(file="postprints.pdf")
data %>% ggplot(aes(Postprints))+ geom_bar()
dev.off()

## And embargo periods

summary(data$Postprint.embargo..months.)

pdf(file="embargo.pdf")
data %>% ggplot(aes(Postprint.embargo..months.))+ geom_bar()
dev.off()

## Sharing of VOR

summary(data$Publisher.version..VOR.)

pdf(file="vor.pdf")
data %>% ggplot(aes(Publisher.version..VOR.))+ geom_bar()
dev.off()

#Sherpa/Romeo

summary(data$Sherpa.Romeo.status)

# Gold OA option

summary(data$Gold.OA.option)

pdf(file="gold.pdf")
data %>% ggplot(aes(Gold.OA.option))+ geom_bar()
dev.off()

## Publishers

summary(data$Publisher)

## SNIP

summary(data$X2017.SNIP)

pdf(file="snip.pdf")
data %>% ggplot(aes(X2017.SNIP)) + geom_histogram()
dev.off()

## APC data

summary(data$APC...USD.)

pdf(file="apc.pdf")
data %>% ggplot(aes(APC...USD.)) + geom_histogram()
dev.off()

## Impact factor

summary(data$X2017.Impact.Factor) #Not very useful..

data %>% ggplot(aes(X2017.Impact.Factor)) + geom_histogram() #Does not work too well

ggplot(data, aes(X2017.Impact.Factor), na.rm=TRUE) + geom_histogram() #Nor does this one

IF<-data$X2017.Impact.Factor
IF<-as.numeric(levels(IF))[IF] # Because the data are a bit weird with the NAs

pdf(file = "impact_factor.pdf")
data %>% ggplot(aes(IF)) + geom_histogram()
dev.off()

## Make comparison plots for APC, SNIP, IF

pdf(file = "apc_if.pdf")
ggplot(data, aes(x=APC...USD., y=IF), na.rm=TRUE) + geom_point() + geom_smooth(method=lm)
dev.off()

pdf(file = "apc_snip.pdf")
ggplot(data, aes(x=APC...USD., y=X2017.SNIP), na.rm=TRUE) + geom_point() + geom_smooth(method=lm)
dev.off()

pdf(file = "snip_if.pdf")
ggplot(data, aes(x=X2017.SNIP, y=IF), na.rm=TRUE) + geom_point() + geom_smooth(method=lm)
dev.off()

## Make comparison plots for APC, SNIP, IF - Same but with logged data (looks better)

pdf(file = "apc_if.pdf")
ggplot(data, aes(x=APC...USD., y=IF), na.rm=TRUE) + geom_point() + geom_smooth(method=lm) + scale_y_log10() + scale_x_log10()
dev.off()

fit1<-lm(data$APC...USD. ~ IF, data=data)
summary(fit1)

pdf(file = "apc_snip.pdf")
ggplot(data, aes(x=APC...USD., y=X2017.SNIP), na.rm=TRUE) + geom_point() + geom_smooth(method=lm) + scale_y_log10() + scale_x_log10()
dev.off()

fit2<-lm(data$APC...USD. ~ data$X2017.SNIP)
summary(fit2)

pdf(file = "snip_if.pdf")
ggplot(data, aes(x=X2017.SNIP, y=IF), na.rm=TRUE) + geom_point() + geom_smooth(method=lm) + scale_y_log10() + scale_x_log10()
dev.off()

fit3<-lm(data$X2017.SNIP ~ IF)
summary(fit3)

## Some basic stats (with results shown)

cor.test(data$APC...USD.,IF,method="spearman")

# Spearman's rank correlation rho
#
# data:  data$APC...USD. and IF
# S = 200470, p-value = 6.433e-12
# alternative hypothesis: true rho is not equal to 0
# sample estimates:
#      rho 
# 0.5422881 

cor.test(data$X2017.SNIP,IF,method="spearman")

# Spearman's rank correlation rho
#
# data:  data$X2017.SNIP and IF
# S = 88767, p-value < 2.2e-16
# alternative hypothesis: true rho is not equal to 0
# sample estimates:
#      rho 
# 0.8483324 

cor.test(data$X2017.SNIP,data$APC...USD.,method="spearman")

# Spearman's rank correlation rho
#
# data:  data$X2017.SNIP and data$APC...USD.
# S = 303840, p-value = 5.399e-07
# alternative hypothesis: true rho is not equal to 0
# sample estimates:
#      rho 
# 0.4019758 